@@ -501,7 +501,7 @@ gboolean xa_create_working_directory (XArchive *archive)
 	if (archive->working_dir)
 		return TRUE;
 
-	value = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_temp_dir));
+	value = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->preferred_temp_dir));
 
 	if (value && *value)
 	{
@@ -764,6 +764,16 @@ XEntry* xa_find_entry_from_dirpath (XArchive *archive, const gchar *dirpath)
 
 	components = g_strsplit(dirpath, "/", -1);
 
+	if (*dirpath == '/')
+	{
+		gchar *slashdir;
+
+		n = 1;
+		slashdir = g_strconcat("/", components[n], NULL);
+		g_free(components[n]);
+		components[n] = slashdir;
+	}
+
 	while (components[n] && *components[n])
 	{
 		entry = xa_find_directory_entry(root->child, components[n]);
