@@ -17,6 +17,7 @@
  *  MA 02110-1301 USA.
  */
 
+#include <stdio.h>
 #include <string.h>
 #include "cpio.h"
 #include "date_utils.h"
@@ -32,6 +33,29 @@ static void relative_path (char *filename, gpointer user_data)
 		strcpy(filename, filename + 1);
 }
 
+gboolean xa_cpio_check_version (gchar *path)
+{
+	gchar *command, *output = NULL;
+	int major, minor;
+	gboolean result = FALSE;
+
+	command = g_strconcat(path, " --version", NULL);
+	g_spawn_command_line_sync(command, &output, NULL, NULL, NULL);
+	g_free(command);
+
+	if (output)
+	{
+		if (strncmp(output, "cpio (GNU cpio) ", 16) == 0)
+			if (sscanf(output + 16, "%d.%d", &major, &minor) == 2)
+				/* cpio as of version 2.13 is safe */
+				result = ((major == 2 && minor > 12) || major > 2);
+
+		g_free(output);
+	}
+
+	return result;
+}
+
 void xa_cpio_ask (XArchive *archive)
 {
 	archive->can_extract = TRUE;
@@ -40,6 +64,7 @@ void xa_cpio_ask (XArchive *archive)
 	archive->can_full_path[1] = TRUE;   // n.b.: adds leading slash
 	archive->can_touch = TRUE;
 	archive->can_overwrite = TRUE;
+	archive->can_recurse[0] = TRUE;
 }
 
 void xa_cpio_parse_output (gchar *line, XArchive *archive)
@@ -172,7 +197,7 @@ gboolean xa_cpio_extract (XArchive *archive, GSList *file_list)
 	}
 
 	g_slist_foreach(file_list, (GFunc) relative_path, NULL);
-	files = xa_quote_filenames(file_list, "*?[]\"", FALSE);
+	files = xa_quote_filenames(file_list, "*?[]\"", DIR_WITH_ASTERISK);
 	archive->child_dir = g_strdup(extract_to);
 	command = g_strconcat(archiver[archive->type].program[0], " -id",
 	                      archive->do_touch ? "" : " -m",
@@ -215,7 +240,7 @@ void xa_cpio_add (XArchive *archive, GSList *file_list)
 	GString *files;
 	gchar *archive_path, *command;
 
-	files = xa_quote_filenames(file_list, "\"", FALSE);
+	files = xa_quote_filenames(file_list, "\"", DIR_WITH_SLASH);
 	archive_path = xa_quote_shell_command(archive->path[0], TRUE);
 	command = g_strconcat("sh -c \"", "exec ls -d --", files->str, " | ",
 	                      archiver[archive->type].program[0], " -o",
