@@ -24,29 +24,48 @@
 #include <gtk/gtk.h>
 #include "archive.h"
 
-typedef struct Extract_dialog_data
+typedef struct ExtractDialog
 {
-	GtkWidget *dialog1, *dialog_vbox1, *destination_path_entry, *ensure_directory, *overwrite_check, *touch, *fresh, *update, *all_files_radio, *files_radio, *selected_radio, *entry2, *full_paths_radio, *relative_paths_radio, *no_paths_radio, *password_entry;
-	gchar *string;
+	GtkWidget *dialog;
+	GtkWidget *destination_path_entry;
+	GtkWidget *ensure_directory;
+	GtkWidget *all_files;
+	GtkWidget *selected_files;
+	GtkWidget *specified_files;
+	GtkWidget *specified_files_entry;
+	GtkWidget *full_path;
+	GtkWidget *relative_path;
+	GtkWidget *without_path;
+	GtkWidget *touch;
+	GtkWidget *overwrite;
+	GtkWidget *update;
+	GtkWidget *freshen;
+	GtkWidget *label_password;
+	GtkWidget *password_entry;
 	XArchive *archive;
-} Extract_dialog_data;
+} ExtractDialog;
 
-typedef struct Multi_extract_data
+typedef struct MultiExtractDialog
 {
-	GtkWidget *multi_extract, *files_treeview, *hbox2, *extract_to, *entry1, *extract_to_archive_name, *label1, *frame2, *alignment2, *vbox3, *overwrite, *full_path, *label2,
-	*extract_button,*extract_image,*extract_hbox,*extract_label,*image1;
-	GtkListStore *files_liststore;
+	GtkWidget *dialog;
+	GtkWidget *treeview;
+	GtkWidget *remove;
+	GtkWidget *extract_to;
+	GtkWidget *destination_path_entry;
+	GtkWidget *overwrite;
+	GtkWidget *full_path;
+	GtkListStore *liststore;
 	gint nr;
 	gboolean stop_pressed;
 	XArchive *archive;
-} Multi_extract_data;
+} MultiExtractDialog;
 
-Extract_dialog_data *xa_create_extract_dialog();
-Multi_extract_data *xa_create_multi_extract_dialog();
+ExtractDialog *xa_create_extract_dialog();
+MultiExtractDialog *xa_create_multi_extract_dialog();
 void xa_execute_extract_commands(XArchive *, GSList *, gboolean);
-void xa_multi_extract_dialog(Multi_extract_data *);
-void xa_multi_extract_dialog_add_file(gchar *, Multi_extract_data *);
-void xa_parse_extract_dialog_options(XArchive * , Extract_dialog_data *, GtkTreeSelection *);
-void xa_set_extract_dialog_options(Extract_dialog_data *, gint, XArchive *);
+void xa_multi_extract_dialog(MultiExtractDialog *);
+void xa_multi_extract_dialog_add_file(gchar *, MultiExtractDialog *);
+void xa_parse_extract_dialog_options(XArchive * , ExtractDialog *, GtkTreeSelection *);
+void xa_set_extract_dialog_options(ExtractDialog *, gint, XArchive *);
 
 #endif
