@@ -318,7 +318,7 @@ failed:
 	archive[idx]->do_update = FALSE;
 	archive[idx]->do_freshen = FALSE;
 	archive[idx]->do_recurse = FALSE;
-	archive[idx]->do_move = FALSE;
+	archive[idx]->do_remove = FALSE;
 	archive[idx]->do_solid = FALSE;
 
 	recurse = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->allow_sub_dir));
@@ -512,9 +512,8 @@ static void xa_select_by_pattern_dialog (GtkMenuItem *menuitem, gpointer user_da
 	GtkWidget *pattern_label;
 	GtkWidget *pattern_entry;
 	GtkWidget *cancelbutton1;
-	GtkWidget *okbutton1;
-	GtkWidget *tmp_image,*select_hbox,*select_label;
-	GtkWidget *alignment2;
+	GtkWidget *select, *image, *label, *hbox;
+	GtkWidget *alignment;
 	gchar *string;
 	gboolean done = FALSE;
 	gint idx;
@@ -548,21 +547,24 @@ static void xa_select_by_pattern_dialog (GtkMenuItem *menuitem, gpointer user_da
 	gtk_widget_show (cancelbutton1);
 	gtk_dialog_add_action_widget (GTK_DIALOG (ddialog1),cancelbutton1,GTK_RESPONSE_CANCEL);
 
-	okbutton1 = gtk_button_new();
-	tmp_image = xa_main_window_find_image("xarchiver-select.png", GTK_ICON_SIZE_BUTTON);
-	select_hbox = gtk_hbox_new(FALSE,4);
-	select_label = gtk_label_new_with_mnemonic(_("_Select"));
+	select = gtk_button_new();
 
-	alignment2 = gtk_alignment_new (0.5,0.5,0,0);
-	gtk_container_add (GTK_CONTAINER (alignment2),select_hbox);
+	image = xa_main_window_find_image("xarchiver-select.png", GTK_ICON_SIZE_BUTTON);
+	label = gtk_label_new_with_mnemonic(_("_Select"));
 
-	gtk_box_pack_start(GTK_BOX(select_hbox),tmp_image,FALSE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(select_hbox),select_label,FALSE,TRUE,0);
-	gtk_container_add(GTK_CONTAINER(okbutton1),alignment2);
-	gtk_widget_show_all (okbutton1);
-	gtk_dialog_add_action_widget (GTK_DIALOG (ddialog1),okbutton1,GTK_RESPONSE_OK);
-	gtk_widget_set_can_default(okbutton1, TRUE);
-	gtk_dialog_set_default_response (GTK_DIALOG (ddialog1),GTK_RESPONSE_OK);
+	hbox = gtk_hbox_new(FALSE, 4);
+	gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+
+	alignment = gtk_alignment_new(0.5, 0.5, 0, 1);
+	gtk_container_add(GTK_CONTAINER(alignment), hbox);
+	gtk_container_add(GTK_CONTAINER(select), alignment);
+	gtk_widget_show_all(select);
+
+	gtk_dialog_add_action_widget(GTK_DIALOG(ddialog1), select, GTK_RESPONSE_OK);
+	gtk_widget_set_can_default(select, TRUE);
+
+	gtk_dialog_set_default_response(GTK_DIALOG(ddialog1), GTK_RESPONSE_OK);
 
 	while (! done)
 	{
@@ -1196,7 +1198,7 @@ void xa_create_main_window (GtkWidget *xa_main_window, gboolean show_location, g
 	gtk_frame_set_shadow_type (GTK_FRAME (total_frame),GTK_SHADOW_IN);
 
 	total_label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC(total_label),0.0,0.5);
+	gtk_misc_set_alignment(GTK_MISC(total_label), 0, 0.5);
 	gtk_widget_show (total_label);
 	gtk_container_add (GTK_CONTAINER (total_frame),total_label);
 
@@ -1206,7 +1208,7 @@ void xa_create_main_window (GtkWidget *xa_main_window, gboolean show_location, g
 	gtk_frame_set_shadow_type (GTK_FRAME (selected_frame),GTK_SHADOW_IN);
 
 	selected_label = gtk_label_new (NULL);
-	gtk_misc_set_alignment (GTK_MISC(selected_label),0.0,0.5);
+	gtk_misc_set_alignment(GTK_MISC(selected_label), 0, 0.5);
 	gtk_widget_show (selected_label);
 	gtk_container_add (GTK_CONTAINER (selected_frame),selected_label);
 
@@ -1343,12 +1345,12 @@ void xa_add_page (XArchive *archive)
 
 	image = xa_main_window_find_image("xarchiver-close.png", 8);
 	gtk_container_add (GTK_CONTAINER(close_button),image);
-	align = gtk_alignment_new(1.0, 0.5, 0.0, 0.0);
+	align = gtk_alignment_new(1, 0.5, 0, 1);
 	gtk_container_add(GTK_CONTAINER(align),close_button);
 	gtk_box_pack_start(GTK_BOX(page_hbox),align,TRUE,TRUE,0);
 	gtk_widget_show_all(page_hbox);
 
-	gtk_misc_set_alignment(GTK_MISC(tab_label),0.0,0);
+	gtk_misc_set_alignment(GTK_MISC(tab_label), 0, 0);
 	gtk_notebook_append_page_menu(notebook, archive->page, page_hbox, tab_label);
 	gtk_notebook_set_current_page(notebook,-1);
 	gtk_notebook_set_tab_reorderable(notebook, archive->page, TRUE);
@@ -1385,7 +1387,7 @@ gboolean xa_check_password (XArchive *archive)
 		return TRUE;
 
   	password_dialog = gtk_dialog_new_with_buttons(PACKAGE_NAME,
-									GTK_WINDOW (xa_main_window),GTK_DIALOG_DESTROY_WITH_PARENT,
+									GTK_WINDOW(xa_main_window), (GtkDialogFlags) 0,
 									GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,GTK_STOCK_OK,GTK_RESPONSE_OK,NULL);
 
   	gtk_container_set_border_width (GTK_CONTAINER (password_dialog),6);
@@ -1513,7 +1515,7 @@ GtkWidget *xa_create_archive_properties_window()
 	GtkWidget *archiver_label;
 
 	archive_properties_window = gtk_dialog_new_with_buttons (_("Archive Properties"),
-									GTK_WINDOW (xa_main_window),GTK_DIALOG_DESTROY_WITH_PARENT,
+									GTK_WINDOW(xa_main_window), (GtkDialogFlags) 0,
 									GTK_STOCK_CLOSE,GTK_RESPONSE_CANCEL,NULL);
 
 	g_signal_connect(archive_properties_window,"response",G_CALLBACK(gtk_widget_destroy),NULL);
@@ -1729,7 +1731,7 @@ void xa_show_progress_bar (XArchive *archive)
 	g_object_unref(pixbuf);
 
 	gtk_box_pack_start (GTK_BOX (hbox1),icon_pixbuf,FALSE,FALSE,0);
-	gtk_misc_set_alignment (GTK_MISC (icon_pixbuf),0.0,0.0);
+	gtk_misc_set_alignment(GTK_MISC(icon_pixbuf), 0, 0);
 
 	vbox2 = gtk_vbox_new (FALSE,0);
 	gtk_box_pack_start (GTK_BOX (hbox1),vbox2,TRUE,TRUE,0);
