@@ -55,10 +55,10 @@ XArchiver archiver[XARCHIVETYPE_TYPES];
 
 gchar *xdg_open;
 
-Add_dialog_data *add_window;
-Extract_dialog_data *extract_window;
-Multi_extract_data *multi_extract_window;
-Prefs_dialog_data *prefs_window;
+AddDialog *add_window;
+ExtractDialog *extract_window;
+MultiExtractDialog *multi_extract_window;
+PrefsDialog *prefs_window;
 
 static gchar *opt_extract_path, *opt_compress;
 static gboolean opt_extract, opt_ensure_dir, opt_multi_extract, opt_add, opt_info, opt_version;
@@ -1264,7 +1264,7 @@ int main (int argc, char **argv)
 	GError *cli_error = NULL;
 	XArchive *archive;
 	gchar *current_dir;
-	int i, result = -1;
+	int i, result = EXIT_FAILURE;
 
 #ifdef ENABLE_NLS
 	GTK_COMPAT_PARAMETER_STRING;
@@ -1291,23 +1291,21 @@ int main (int argc, char **argv)
 	{
 		g_print (_("xarchiver: %s\nTry xarchiver --help to see a full list of available command-line options.\n"),cli_error->message);
 		g_error_free (cli_error);
-		return 0;
+		goto quit;
 	}
-    /* print version information */
-    if (opt_version)
-    {
-        g_print("%s %s\n\n", PACKAGE_NAME, PACKAGE_VERSION);
-        g_print ("%s\n", "Copyright (c) " COPYRIGHT_YEAR);
-        g_print ("\t%s\n", COPYRIGHT_HOLDER " - Colossus <colossus73@gmail.com>");
-        g_print ("%s\n", "Copyright \xC2\xA9 " MAINTAINER_YEAR);
-        g_print ("\t%s\n\n", MAINTAINER);
-        g_print (_("Maintained by "));
-        g_print (MAINTAINER ".\n\n");
-        g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
-        g_print ("\n");
 
-        return EXIT_SUCCESS;
-    }
+	/* print version information */
+	if (opt_version)
+	{
+		g_print("%s %s\n\n", PACKAGE_NAME, PACKAGE_VERSION);
+		g_print (_("Maintained by "));
+		g_print (MAINTAINER ".\n\n");
+		g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
+		g_print ("\n");
+
+		result = EXIT_SUCCESS;
+		goto quit;
+	}
 
 	xdg_open = g_find_program_in_path("xdg-open");
 
@@ -1323,8 +1321,7 @@ int main (int argc, char **argv)
 	if (opt_extract || opt_extract_path || opt_ensure_dir || opt_multi_extract || opt_add || opt_compress || opt_info)
 	{
 		archive = xa_init_structure_from_cmd_line (argv[1]);
-		g_print(PACKAGE_NAME " 0.5.4 \xC2\xA9  " COPYRIGHT_YEAR " " COPYRIGHT_HOLDER "\n");
-		g_print(PACKAGE_NAME " %-8s " MAINTAINER "\n", VERSION);
+		g_print(PACKAGE_NAME " %s\n", VERSION);
 
 		/* Switches -d and -x */
 		if (opt_ensure_dir || opt_extract_path)
@@ -1380,7 +1377,7 @@ int main (int argc, char **argv)
 			archive->do_overwrite = TRUE;
 			archive->do_touch = FALSE;
 			archive->extraction_dir = xa_escape_bad_chars(opt_extract_path, ESCAPES);
-			g_free(extraction_dir);
+			g_free(opt_extract_path);
 
 			archive->status = XARCHIVESTATUS_EXTRACT;
 			(*archive->archiver->extract)(archive, NULL);
@@ -1413,30 +1410,23 @@ int main (int argc, char **argv)
 
 			xa_set_extract_dialog_options(extract_window,0,archive);
 			xa_parse_extract_dialog_options (archive,extract_window,NULL);
-			gtk_widget_destroy (extract_window->dialog1);
-			g_free (extract_window);
 		}
 		/* Switch -m */
 		else if (opt_multi_extract)
 		{
-			Multi_extract_data *multi_extract;
 			gchar *arg;
 
-			multi_extract = xa_create_multi_extract_dialog();
-
 			for (i = 1; i < argc; i++)
 			{
 				arg = xa_make_full_path(argv[i]);
 
 				if (!g_file_test(arg, G_FILE_TEST_IS_DIR))
-					xa_multi_extract_dialog_add_file(arg, multi_extract);
+					xa_multi_extract_dialog_add_file(arg, multi_extract_window);
 
 				g_free(arg);
 			}
 
-			xa_multi_extract_dialog(multi_extract);
-			gtk_widget_destroy (multi_extract->multi_extract);
-			g_free(multi_extract);
+			xa_multi_extract_dialog(multi_extract_window);
 		}
 		/* Switch -c */
 		else if (opt_compress)
@@ -1459,7 +1449,7 @@ int main (int argc, char **argv)
 			if (archive->path[0] != NULL)
 			{
 				gchar *fname;
-				gboolean is_dir, recurse;
+				gboolean is_dir;
 				GSList *files = NULL;
 
 				fname = xa_make_full_path(opt_compress);
@@ -1475,34 +1465,19 @@ int main (int argc, char **argv)
 
 				xa_create_working_directory(archive);
 
-				archive->child_dir = g_path_get_dirname(opt_compress);
-
-				fname = g_path_get_basename(opt_compress);
-				files = g_slist_append(files, fname);
-				g_free(opt_compress);
+				files = g_slist_append(files, opt_compress);
 
 				for (i = 1; i < argc; i++)
-				{
-					fname = g_path_get_basename(argv[i]);
-					files = g_slist_append(files, fname);
-				}
+					files = g_slist_append(files, g_strdup(argv[i]));
 
-				archive->do_full_path = FALSE;
-				archive->do_update = FALSE;
-				archive->do_freshen = FALSE;
-				archive->do_recurse = FALSE;
-				archive->do_move = FALSE;
-				archive->do_solid = FALSE;
-
-				recurse = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->allow_sub_dir));
-
-				if (archive->can_recurse[1])
-				{
-					archive->do_recurse = (recurse || (archive->can_recurse[1] == FORCED));
-					recurse = FALSE;
-				}
-
-				xa_execute_add_commands(archive, files, recurse, !archive->do_recurse);
+				prefs_window->add_win_size[0] = -1;
+				xa_set_add_dialog_options(add_window, archive);
+				gtk_widget_hide(gtk_notebook_get_nth_page(GTK_NOTEBOOK(add_window->notebook), 0));
+				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(add_window->update), FALSE);
+				gtk_widget_hide(add_window->update);
+				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(add_window->freshen), FALSE);
+				gtk_widget_hide(add_window->freshen);
+				xa_parse_add_dialog_options(archive, add_window, files);
 			}
 		}
 		/* Switch -a */
@@ -1531,9 +1506,7 @@ int main (int argc, char **argv)
 			}
 
 			xa_set_add_dialog_options(add_window, archive);
-			xa_parse_add_dialog_options(archive, add_window);
-			gtk_widget_destroy(add_window->dialog1);
-			g_free(add_window);
+			xa_parse_add_dialog_options(archive, add_window, NULL);
 		}
 		/* Switch -i */
 		else if (opt_info)
@@ -1573,17 +1546,8 @@ int main (int argc, char **argv)
 
 leave:
 
-		if (progress)
-		{
-			gtk_widget_destroy(progress->window);
-			g_free(progress);
-			progress = NULL;
-		}
-		if (archive != NULL)
-			xa_clean_archive_structure (archive);
-		#ifdef HAVE_SOCKET
-			socket_finalize();
-		#endif
+		if (archive)
+			xa_clean_archive_structure(archive);
 	}
 	else
 	{
@@ -1592,15 +1556,15 @@ leave:
 												gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (prefs_window->show_sidebar)),
 												gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (prefs_window->show_toolbar)));
 
-		gtk_window_set_transient_for (GTK_WINDOW (extract_window->dialog1),GTK_WINDOW (xa_main_window));
-		gtk_window_set_transient_for (GTK_WINDOW (add_window->dialog1),GTK_WINDOW (xa_main_window));
-		gtk_window_set_transient_for (GTK_WINDOW (prefs_window->dialog1),GTK_WINDOW (xa_main_window));
-		gtk_window_set_transient_for (GTK_WINDOW (multi_extract_window->multi_extract),GTK_WINDOW (xa_main_window));
-		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->check_save_geometry)) && prefs_window->geometry[0] != -1)
+		gtk_window_set_transient_for(GTK_WINDOW(extract_window->dialog), GTK_WINDOW(xa_main_window));
+		gtk_window_set_transient_for(GTK_WINDOW(add_window->dialog), GTK_WINDOW(xa_main_window));
+		gtk_window_set_transient_for(GTK_WINDOW(prefs_window->dialog), GTK_WINDOW(xa_main_window));
+		gtk_window_set_transient_for(GTK_WINDOW(multi_extract_window->dialog), GTK_WINDOW(xa_main_window));
+		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->save_geometry)) && prefs_window->main_win_geometry[0] != -1)
 		{
-			gtk_window_move (GTK_WINDOW(xa_main_window), prefs_window->geometry[0], prefs_window->geometry[1]);
-			gtk_window_set_default_size(GTK_WINDOW(xa_main_window), prefs_window->geometry[2], prefs_window->geometry[3]);
-			gtk_paned_set_position(GTK_PANED(hpaned1), prefs_window->geometry[4]);
+			gtk_window_move(GTK_WINDOW(xa_main_window), prefs_window->main_win_geometry[0], prefs_window->main_win_geometry[1]);
+			gtk_window_set_default_size(GTK_WINDOW(xa_main_window), prefs_window->main_win_geometry[2], prefs_window->main_win_geometry[3]);
+			gtk_paned_set_position(GTK_PANED(hpaned1), prefs_window->main_win_geometry[4]);
 		}
 		else
 		{
@@ -1640,6 +1604,26 @@ leave:
 		result = EXIT_SUCCESS;
 	}
 
+	if (progress)
+	{
+		gtk_widget_destroy(progress->window);
+		g_free(progress);
+	}
+
+	gtk_widget_destroy(prefs_window->dialog);
+	g_free(prefs_window);
+	g_free(config_file);
+	g_free(xdg_open);
+
+	gtk_widget_destroy(extract_window->dialog);
+	g_free(extract_window);
+
+	gtk_widget_destroy(add_window->dialog);
+	g_free(add_window);
+
+	gtk_widget_destroy(multi_extract_window->dialog);
+	g_free(multi_extract_window);
+
 	for (i = XARCHIVETYPE_FIRST; i < XARCHIVETYPE_TYPES; i++)
 	{
 		g_free(archiver[i].program[0]);
@@ -1649,7 +1633,11 @@ leave:
 		g_slist_free(archiver[i].tags);
 	}
 
-	g_free(xdg_open);
+quit:
+
+#ifdef HAVE_SOCKET
+	socket_finalize();
+#endif
 
 	return result;
 }
