@@ -119,7 +119,7 @@ void xa_tar_ask (XArchive *archive)
 	archive->can_update[1] = archiver[xa_tar_get_compressor_type(archive)].is_compressor;
 	archive->can_recurse[0] = TRUE;
 	archive->can_recurse[1] = TRUE;
-	archive->can_move = archiver[xa_tar_get_compressor_type(archive)].is_compressor;
+	archive->can_remove = archiver[xa_tar_get_compressor_type(archive)].is_compressor;
 
 	/* this is solely for display with the archive properties */
 	if (!archiver[archive->type].program[0])
@@ -303,7 +303,7 @@ void xa_tar_add (XArchive *archive, GSList *file_list)
 		command = g_strconcat(archiver[XARCHIVETYPE_TAR].program[0],
 		                      " -c --no-wildcards",
 		                      archive->do_recurse ? "" : " --no-recursion",
-		                      archive->do_move ? " --remove-files" : "",
+		                      archive->do_remove ? " --remove-files" : "",
 		                      " -f ", archive->path[2], " --", files->str, NULL);
 	}
 	else
@@ -311,7 +311,7 @@ void xa_tar_add (XArchive *archive, GSList *file_list)
 		                      archive->do_update ? " -u" : " -r",
 		                      " --no-wildcards",
 		                      archive->do_recurse ? "" : " --no-recursion",
-		                      archive->do_move ? " --remove-files" : "",
+		                      archive->do_remove ? " --remove-files" : "",
 		                      " -f ", archive->path[2], " --", files->str, NULL);
 
 	if (archive->type != XARCHIVETYPE_TAR)
