@@ -90,14 +90,12 @@ static gchar *xa_open_file_dialog ()
 
 	if (File_Selector == NULL)
 	{
-		File_Selector = gtk_file_chooser_dialog_new ( _("Open an archive"),
-						GTK_WINDOW (xa_main_window),
-						GTK_FILE_CHOOSER_ACTION_OPEN,
-						GTK_STOCK_CANCEL,
-						GTK_RESPONSE_CANCEL,
-						"gtk-open",
-						GTK_RESPONSE_ACCEPT,
-						NULL);
+		File_Selector = gtk_file_chooser_dialog_new(_("Open an archive"),
+		                                            GTK_WINDOW(xa_main_window),
+		                                            GTK_FILE_CHOOSER_ACTION_OPEN,
+		                                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		                                            GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+		                                            NULL);
 
 		gtk_dialog_set_default_response (GTK_DIALOG (File_Selector),GTK_RESPONSE_ACCEPT);
 		gtk_window_set_destroy_with_parent (GTK_WINDOW (File_Selector) ,TRUE);
@@ -237,7 +235,7 @@ static gboolean xa_detect_archive_comment (int type, gchar *filename, XArchive *
 		{
 			if (fread(&sig, sizeof(sig), 1, stream) != 1 || (sig == 0 && archive->comment->len == 0))
 			{
-				g_string_free (archive->comment,FALSE);
+				g_string_free(archive->comment, TRUE);
 				archive->comment = NULL;
 				fclose(stream);
 				return FALSE;
@@ -348,14 +346,12 @@ static gchar *xa_open_sfx_file_selector ()
 	GtkWidget *sfx_file_selector = NULL;
 	int response;
 
-	sfx_file_selector = gtk_file_chooser_dialog_new ( _("Save the self-extracting archive as"),
-						GTK_WINDOW (xa_main_window),
-						GTK_FILE_CHOOSER_ACTION_SAVE,
-						GTK_STOCK_CANCEL,
-						GTK_RESPONSE_CANCEL,
-						"gtk-save",
-						GTK_RESPONSE_ACCEPT,
-						NULL);
+	sfx_file_selector = gtk_file_chooser_dialog_new(_("Save the self-extracting archive as"),
+	                                                GTK_WINDOW(xa_main_window),
+	                                                GTK_FILE_CHOOSER_ACTION_SAVE,
+	                                                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+	                                                GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+	                                                NULL);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (sfx_file_selector),GTK_RESPONSE_ACCEPT);
 	gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER (sfx_file_selector),TRUE);
@@ -373,7 +369,7 @@ static void xa_activate_link (GtkAboutDialog *about, const gchar *link, gpointer
 	if (!xdg_open)
 	{
 		gchar *browser_path = NULL;
-		browser_path = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_web_browser));
+		browser_path = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->preferred_browser));
 		if (!browser_path || !*browser_path)
 		{
 			xa_show_message_dialog (GTK_WINDOW (xa_main_window),GTK_DIALOG_MODAL,GTK_MESSAGE_INFO,GTK_BUTTONS_OK,_("You didn't set which browser to use!"),_("Please go to Preferences->Advanced and set it."));
@@ -459,10 +455,11 @@ static void xa_rename_cell_edited (GtkCellRendererText *cell, const gchar *path_
 		archive->do_update = FALSE;
 		archive->do_freshen = FALSE;
 		archive->do_recurse = FALSE;
-		archive->do_move = FALSE;
+		archive->do_remove = FALSE;
 		archive->do_solid = FALSE;
 
 		xa_execute_add_commands(archive, file_list, FALSE, TRUE);
+		g_slist_free_full(file_list, g_free);
 	}
 done:
 	xa_rename_cell_edited_canceled(GTK_CELL_RENDERER(cell), NULL);
@@ -529,16 +526,16 @@ static void xa_determine_program_to_run (gchar *file)
 
 		if (strcmp(type, "text-html") == 0)
 		{
-			program = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_web_browser));
+			program = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->preferred_browser));
 		}
 		else if (strcmp(type, "text-x-generic") == 0)
 		{
-			program = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_editor));
+			program = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->preferred_editor));
 		}
 		else if (strcmp(type, "image-x-generic") == 0)
-			program = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_viewer));
+			program = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->preferred_viewer));
 		else if (strcmp(type, "package-x-generic") == 0)
-			program = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_archiver));
+			program = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->preferred_archiver));
 		else
 		{
 			gchar *basename_utf8 = g_filename_display_name(basename);
@@ -584,14 +581,12 @@ static void xa_load_comment_window_from_file (GtkButton *button, gpointer buf)
 	gboolean response;
 	gsize bytes;
 
-	file = gtk_file_chooser_dialog_new (_("Open a text file"),
-						GTK_WINDOW (xa_main_window),
-						GTK_FILE_CHOOSER_ACTION_OPEN,
-						GTK_STOCK_CANCEL,
-						GTK_RESPONSE_CANCEL,
-						"gtk-open",
-						GTK_RESPONSE_ACCEPT,
-						NULL);
+	file = gtk_file_chooser_dialog_new(_("Open a text file"),
+	                                   GTK_WINDOW(xa_main_window),
+	                                   GTK_FILE_CHOOSER_ACTION_OPEN,
+	                                   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+	                                   GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+	                                   NULL);
 
 	response = gtk_dialog_run (GTK_DIALOG(file));
 	if (response == GTK_RESPONSE_ACCEPT)
@@ -827,7 +822,7 @@ void xa_child_processed (XAChildProcess process, guint8 exitstatus, XArchive *ar
 
 				xa_set_statusbar_message_for_displayed_rows(archive);
 
-				if (archive->status == XARCHIVESTATUS_LIST && archive->has_comment && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->check_show_comment)))
+				if (archive->status == XARCHIVESTATUS_LIST && archive->has_comment && gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->show_comment)))
 					xa_show_archive_comment(NULL, NULL);
 
 				if (archive->status == XARCHIVESTATUS_TEST)
@@ -951,7 +946,7 @@ void xa_show_archive_output (GtkMenuItem *menuitem, XArchive *this_archive)
 	if (!menuitem)
 	{
 		image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_ERROR,GTK_ICON_SIZE_DIALOG);
-		gtk_misc_set_alignment (GTK_MISC (image),0.5,0.0);
+		gtk_misc_set_alignment(GTK_MISC(image), 0.5, 0);
 
 		label = gtk_label_new (_("An error occurred while accessing the archive:"));
 		hbox = gtk_hbox_new (FALSE,6);
@@ -1034,14 +1029,13 @@ void xa_save_archive (GtkMenuItem *menuitem, gpointer user_data)
 
 	idx = xa_find_archive_index(gtk_notebook_get_current_page(notebook));
 
-	save = gtk_file_chooser_dialog_new (_("Save the archive as"),
-						GTK_WINDOW (xa_main_window),
-						GTK_FILE_CHOOSER_ACTION_SAVE,
-						GTK_STOCK_CANCEL,
-						GTK_RESPONSE_CANCEL,
-						"gtk-save",
-						GTK_RESPONSE_ACCEPT,
-						NULL);
+	save = gtk_file_chooser_dialog_new(_("Save the archive as"),
+	                                   GTK_WINDOW(xa_main_window),
+	                                   GTK_FILE_CHOOSER_ACTION_SAVE,
+	                                   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+	                                   GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+	                                   NULL);
+
 	filename = g_path_get_basename(archive[idx]->path[1]);
 	filename_utf8 = g_filename_display_name(filename);
 	gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(save), filename_utf8);
@@ -1189,14 +1183,12 @@ void xa_list_archive (GtkMenuItem *menuitem,gpointer data)
 	else
 		_filename = _("Print the archive content as text");
 
-	save = gtk_file_chooser_dialog_new (_filename,
-						GTK_WINDOW (xa_main_window),
-						GTK_FILE_CHOOSER_ACTION_SAVE,
-						GTK_STOCK_CANCEL,
-						GTK_RESPONSE_CANCEL,
-						"gtk-save",
-						GTK_RESPONSE_ACCEPT,
-						NULL);
+	save = gtk_file_chooser_dialog_new(_filename,
+	                                   GTK_WINDOW(xa_main_window),
+	                                   GTK_FILE_CHOOSER_ACTION_SAVE,
+	                                   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+	                                   GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+	                                   NULL);
 
 	filename = g_path_get_basename(archive[idx]->path[1]);
 	_filename = strstr(filename,".");
@@ -1214,7 +1206,7 @@ void xa_list_archive (GtkMenuItem *menuitem,gpointer data)
 	g_free(filename_plus_utf8);
 	filename = NULL;
 
-	pref_path = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->combo_prefered_extract_dir));
+	pref_path = gtk_combo_box_text_get_active_text(GTK_COMBO_BOX_TEXT(prefs_window->preferred_extract_dir));
 
 	if (pref_path && *pref_path)
 		pref_path_local = g_filename_from_utf8(pref_path, -1, NULL, NULL, NULL);
@@ -1376,25 +1368,10 @@ void xa_quit_application (GtkWidget *widget, GdkEvent *event, gpointer user_data
 		g_free (current_open_directory);
 
 	xa_prefs_save_options (prefs_window,config_file);
-	gtk_widget_destroy(prefs_window->dialog1);
-	g_free(prefs_window);
-
-	gtk_widget_destroy (extract_window->dialog1);
-	g_free(extract_window);
-
-	gtk_widget_destroy (add_window->dialog1);
-	g_free(add_window);
-
-	gtk_widget_destroy (multi_extract_window->multi_extract);
-	g_free(multi_extract_window);
 
 	gtk_widget_destroy(xa_popup_menu);
-	g_free (config_file);
 	xa_free_icon_cache();
 
-#ifdef HAVE_SOCKET
-	socket_finalize();
-#endif
 	gtk_main_quit();
 	return;
 }
@@ -1433,7 +1410,7 @@ void xa_add_files_archive (GtkMenuItem *menuitem, gpointer user_data)
 	idx = xa_find_archive_index(gtk_notebook_get_current_page(notebook));
 
 	xa_set_add_dialog_options(add_window,archive[idx]);
-	xa_parse_add_dialog_options (archive[idx],add_window);
+	xa_parse_add_dialog_options(archive[idx], add_window, NULL);
 }
 
 void xa_extract_archive (GtkMenuItem *menuitem,gpointer user_data)
@@ -1455,10 +1432,10 @@ void xa_show_prefs_dialog (GtkMenuItem *menuitem,gpointer user_data)
 	if (prefs_window == NULL)
 		prefs_window = xa_create_prefs_dialog();
 
-	gtk_widget_show_all (prefs_window->dialog1);
+	gtk_widget_show_all(prefs_window->dialog);
 	xa_prefs_iconview_changed(GTK_ICON_VIEW(prefs_window->iconview), prefs_window);
-	response = gtk_dialog_run (GTK_DIALOG(prefs_window->dialog1));
-	gtk_widget_hide (prefs_window->dialog1);
+	response = gtk_dialog_run(GTK_DIALOG(prefs_window->dialog));
+	gtk_widget_hide(prefs_window->dialog);
 
 	if (response == GTK_RESPONSE_OK)
 		xa_prefs_apply_options(prefs_window);
@@ -1589,14 +1566,12 @@ end_zip:
 				gtk_file_filter_set_name (sfx_filter,"");
 				gtk_file_filter_add_pattern (sfx_filter,"*.sfx");
 
-				locate_7zcon = gtk_file_chooser_dialog_new ( _("Please select the 7zCon.sfx module"),
-						GTK_WINDOW (xa_main_window),
-						GTK_FILE_CHOOSER_ACTION_OPEN,
-						GTK_STOCK_CANCEL,
-						GTK_RESPONSE_CANCEL,
-						"gtk-open",
-						GTK_RESPONSE_ACCEPT,
-						NULL);
+				locate_7zcon = gtk_file_chooser_dialog_new(_("Please select the 7zCon.sfx module"),
+				                                           GTK_WINDOW(xa_main_window),
+				                                           GTK_FILE_CHOOSER_ACTION_OPEN,
+				                                           GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				                                           GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+				                                           NULL);
 
 				gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (locate_7zcon),sfx_filter);
 				gtk_dialog_set_default_response (GTK_DIALOG (locate_7zcon),GTK_RESPONSE_ACCEPT);
@@ -1958,7 +1933,7 @@ void xa_create_liststore (XArchive *archive, const gchar *titles[])
 
 	archive->model = GTK_TREE_MODEL(archive->liststore);
 
-	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->check_sort_filename_column)))
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->sort_by_filenames)))
 	{
 		gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(archive->model), 1, GTK_SORT_ASCENDING);
 		archive->sorted = TRUE;
@@ -2020,7 +1995,7 @@ void xa_cancel_archive (GtkMenuItem *menuitem, gpointer user_data)
 	gint idx, response;
 
 	idx = xa_find_archive_index(gtk_notebook_get_current_page(notebook));
-	if (gtk_widget_get_visible(multi_extract_window->multi_extract))
+	if (gtk_widget_get_visible(multi_extract_window->dialog))
 	{
 		multi_extract_window->stop_pressed = TRUE;
 		kill (multi_extract_window->archive->child_pid,SIGINT);
@@ -2400,7 +2375,7 @@ failed:
 		archive[idx]->do_update = FALSE;
 		archive[idx]->do_freshen = FALSE;
 		archive[idx]->do_recurse = FALSE;
-		archive[idx]->do_move = FALSE;
+		archive[idx]->do_remove = FALSE;
 		archive[idx]->do_solid = FALSE;
 
 		recurse = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->allow_sub_dir));
@@ -2501,7 +2476,7 @@ gboolean xa_launch_external_program (const gchar *program, const gchar *arg)
 	if (!GDK_COMPAT_SPAWN(NULL, argv, NULL, G_SPAWN_SEARCH_PATH, xa_set_environment, (gpointer) gdk_display_get_name(display), NULL, &error))
 	{
 		message = gtk_message_dialog_new (GTK_WINDOW (xa_main_window),
-										GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+										GTK_DIALOG_MODAL,
 										GTK_MESSAGE_ERROR,
 										GTK_BUTTONS_CLOSE,
 										_("Failed to launch the application!"));
@@ -2545,8 +2520,7 @@ void xa_show_archive_comment (GtkMenuItem *menuitem,gpointer user_data)
 	GtkWidget *textview;
 	GtkWidget *dialog_vbox1;
 	GtkWidget *scrolledwindow1;
-	GtkWidget *tmp_image,*file,*clear,*close,*cancel,*file_hbox,*file_label;
-	GtkWidget *alignment2;
+	GtkWidget *clear, *file, *image, *label, *hbox, *alignment, *cancel, *close;
 	GtkTextBuffer *textbuffer;
 	GtkTextIter iter;
 
@@ -2576,17 +2550,19 @@ void xa_show_archive_comment (GtkMenuItem *menuitem,gpointer user_data)
 	g_signal_connect (G_OBJECT (clear),"clicked",G_CALLBACK (xa_clear_comment_window),textbuffer);
 
 	file = gtk_button_new();
-	tmp_image = gtk_image_new_from_stock ("gtk-harddisk",GTK_ICON_SIZE_BUTTON);
-	file_hbox = gtk_hbox_new(FALSE,4);
-	file_label = gtk_label_new_with_mnemonic(_("From File"));
+	gtk_dialog_add_action_widget(GTK_DIALOG(comment_dialog), file, 0);
+	g_signal_connect(G_OBJECT(file), "clicked", G_CALLBACK(xa_load_comment_window_from_file), textbuffer);
 
-	alignment2 = gtk_alignment_new (0.5,0.5,0,0);
-	gtk_container_add (GTK_CONTAINER (alignment2),file_hbox);
-	gtk_box_pack_start(GTK_BOX(file_hbox),tmp_image,FALSE,TRUE,0);
-	gtk_box_pack_start(GTK_BOX(file_hbox),file_label,FALSE,TRUE,0);
-	gtk_container_add(GTK_CONTAINER(file),alignment2);
-	gtk_dialog_add_action_widget (GTK_DIALOG (comment_dialog),file,0);
-	g_signal_connect (G_OBJECT (file),"clicked",G_CALLBACK (xa_load_comment_window_from_file),textbuffer);
+	image = gtk_image_new_from_stock("gtk-harddisk", GTK_ICON_SIZE_BUTTON);
+	label = gtk_label_new_with_mnemonic(_("From File"));
+
+	hbox = gtk_hbox_new(FALSE, 4);
+	gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+
+	alignment = gtk_alignment_new(0.5, 0.5, 0, 1);
+	gtk_container_add(GTK_CONTAINER(alignment), hbox);
+	gtk_container_add(GTK_CONTAINER(file), alignment);
 
 	cancel = gtk_button_new_from_stock ("gtk-cancel");
 	gtk_dialog_add_action_widget (GTK_DIALOG (comment_dialog),cancel,GTK_RESPONSE_CANCEL);
@@ -2823,7 +2799,7 @@ void xa_clipboard_paste (GtkMenuItem *item, gpointer user_data)
 	archive[idx]->do_update = (XA_Clipboard.mode == XA_CLIPBOARD_EDIT);
 	archive[idx]->do_freshen = FALSE;
 	archive[idx]->do_recurse = FALSE;
-	archive[idx]->do_move = FALSE;
+	archive[idx]->do_remove = FALSE;
 	archive[idx]->do_solid = FALSE;
 
 	recurse = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(prefs_window->allow_sub_dir));
@@ -2954,8 +2930,7 @@ void xa_open_with_from_popupmenu (GtkMenuItem *item, gpointer user_data)
 		list_of_files = list_of_files->next;
 	}
 	while (list_of_files);
-	xa_create_open_with_dialog(entry->filename,names->str,nr);
-	g_string_free(names, FALSE);
+	xa_create_open_with_dialog(entry->filename, g_string_free(names, FALSE), nr);
 	g_slist_free_full(list_of_files, g_free);
 }
 
@@ -3125,7 +3100,7 @@ void xa_update_window_with_archive_entries (XArchive *archive,XEntry *entry)
 		else
 			filename = entry->filename;
 
-		switch (gtk_combo_box_get_active(GTK_COMBO_BOX(prefs_window->combo_icon_size)))
+		switch (gtk_combo_box_get_active(GTK_COMBO_BOX(prefs_window->icon_size)))
 		{
 			case 0:
 				size = 20;
